==> nextcloud-13.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/sr.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Saved" : "Снимљено",
    "Saving failed:" : "Снимање није успело:",
    "File MIME type" : "MIME тип фајла",
    "is" : "је",
    "is not" : "није",
    "matches" : "се поклапа са",
    "does not match" : "се не поклапа са",
    "Example: {placeholder}" : "Пример: {placeholder}",
    "File size (upload)" : "Величина фајла (отпремање)",
    "less" : "је мања од",
    "less or equals" : "мања или једнака од",
    "greater or equals" : "већа или једнака од",
    "greater" : "већа од",
    "File system tag" : "Системска ознака фајла",
    "is tagged with" : "је означен са",
    "is not tagged with" : "није означен са",
    "Select tag…" : "Одаберите ознаку…",
    "Request remote address" : "Захтевај удаљену адресу",
    "matches IPv4" : "поклапа се са  IPv4 адресом",
    "does not match IPv4" : "не поклапа се са IPv4 адресом",
    "matches IPv6" : "поклапа се са IPv6 адресом",
    "does not match IPv6" : "не поклапа се са IPv6 адресом",
    "Request time" : "Време захтева",
    "between" : "између",
    "not between" : "није између",
    "Start" : "Почетак",
    "End" : "Крај",
    "Select timezone…" : "Одаберите временску зону…",
    "Request URL" : "Адреса захтева",
    "Predefined URLs" : "Предефинисане адресе",
    "Files WebDAV" : "WebDAV фајлови",
    "Request user agent" : "Кориснички агент захтева",
    "Sync clients" : "Синхронизовани клијенти",
    "Android client" : "Андроид клијент",
    "iOS client" : "iOS клијент",
    "Desktop client" : "Десктоп клијент",
    "User group membership" : "Припадност групи",
    "is member of" : "је члан групе",
    "is not member of" : "није члан групе",
    "The given operator is invalid" : "Дати оператор није исправан",
    "The given regular expression is invalid" : "Дати регуларни израз није исправан",
    "The given file size is invalid" : "Дата величина фајла није исправна",
    "The given tag id is invalid" : "Дати ИД ознаке није исправан",
    "The given IP range is invalid" : "Дати опсег ИП адреса није исправан",
    "The given IP range is not valid for IPv4" : "Дати опсег ИП адреса није исправан за IPv4",
    "The given IP range is not valid for IPv6" : "Дати опсег ИП адреса није исправан за IPv6",
    "The given time span is invalid" : "Дати временски оквир није исправан",
    "The given start time is invalid" : "Дато време почетка није исправно",
    "The given end time is invalid" : "Дато време краја није исправно",
    "The given group does not exist" : "Дата група не постоји",
    "Check %s is invalid or does not exist" : "Проверите да ли је %s неисправно или не постоји",
    "Operation #%s does not exist" : "Операција #%s не постоји",
    "Operation %s does not exist" : "Операција %s не постоји",
    "Operation %s is invalid" : "Операција %s није исправна",
    "Check %s does not exist" : "Проверите да ли %s постоји",
    "Check %s is invalid" : "Проверите да ли је %s исправно",
    "Check #%s does not exist" : "Проверите да ли #%s постоји",
    "Workflow" : "Процес рада",
    "Files workflow engine" : "Датотеке за мотор процеса рада",
    "Open documentation" : "Отвори документацију",
    "Add rule group" : "Додај групу правила",
    "Short rule description" : "Кратки опис правила",
    "Add rule" : "Додај правило",
    "Reset" : "Ресетуј",
    "Save" : "Сачувај",
    "Saving…" : "Чувам…",
    "Loading…" : "Учитавање…"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/sr.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Group list is empty" : "Списак група је празан",
    "Unable to retrieve the group list" : "Није могуће дохватити списак група",
    "Saved" : "Снимљено",
    "Saving failed:" : "Снимање није успело:",
    "File MIME type" : "MIME тип фајла",
    "is" : "је",
    "is not" : "није",
    "matches" : "се поклапа са",
    "does not match" : "се не поклапа са",
    "Example: {placeholder}" : "Пример: {placeholder}",
    "File size (upload)" : "Величина фајла (отпремање)",
    "less" : "је мања од",
    "less or equals" : "мања или једнака од",
    "greater or equals" : "већа или једнака од",
    "greater" : "већа од",
    "File system tag" : "Системска ознака фајла",
    "is tagged with" : "је означен са",
    "is not tagged with" : "није означен са",
    "Select tag…" : "Одаберите ознаку…",
    "Request remote address" : "Захтевај удаљену адресу",
    "matches IPv4" : "поклапа се са  IPv4 адресом",
    "does not match IPv4" : "не поклапа се са IPv4 адресом",
    "matches IPv6" : "поклапа се са IPv6 адресом",
    "does not match IPv6" : "не поклапа се са IPv6 адресом",
    "Request time" : "Време захтева",
    "between" : "између",
    "not between" : "није између",
    "Start" : "Почетак",
    "End" : "Крај",
    "Select timezone…" : "Одаберите временску зону…",
    "Request URL" : "Адреса захтева",
    "Predefined URLs" : "Предефинисане адресе",
    "Files WebDAV" : "WebDAV фајлови",
    "Request user agent" : "Кориснички агент захтева",
    "Sync clients" : "Синхронизовани клијенти",
    "Android client" : "Андроид клијент",
    "iOS client" : "iOS клијент",
    "Desktop client" : "Десктоп клијент",
    "User group membership" : "Припадност групи",
    "is member of" : "је члан групе",
    "is not member of" : "није члан групе",
    "The given operator is invalid" : "Дати оператор није исправан",
    "The given regular expression is invalid" : "Дати регуларни израз није исправан",
    "The given file size is invalid" : "Дата величина фајла није исправна",
    "The given tag id is invalid" : "Дати ИД ознаке није исправан",
    "The given IP range is invalid" : "Дати опсег ИП адреса није исправан",
    "The given IP range is not valid for IPv4" : "Дати опсег ИП адреса није исправан за IPv4",
    "The given IP range is not valid for IPv6" : "Дати опсег ИП адреса није исправан за IPv6",
    "The given time span is invalid" : "Дати временски оквир није исправан",
    "The given start time is invalid" : "Дато време почетка није исправно",
    "The given end time is invalid" : "Дато време краја није исправно",
    "The given group does not exist" : "Дата група не постоји",
    "Check %s is invalid or does not exist" : "Проверите да ли је %s неисправно или не постоји",
    "Operation #%s does not exist" : "Операција #%s не постоји",
    "Operation %s does not exist" : "Операција %s не постоји",
    "Operation %s is invalid" : "Операција %s није исправна",
    "Check %s does not exist" : "Проверите да ли %s постоји",
    "Check %s is invalid" : "Проверите да ли је %s исправно",
    "Check #%s does not exist" : "Проверите да ли #%s постоји",
    "Workflow" : "Процес рада",
    "Files workflow engine" : "Датотеке за мотор процеса рада",
    "Open documentation" : "Отвори документацију",
    "Add rule group" : "Додај групу правила",
    "Short rule description" : "Кратки опис правила",
    "Add rule" : "Додај правило",
    "Reset" : "Ресетуј",
    "Save" : "Сачувај",
    "Saving…" : "Чувам…",
    "Loading…" : "Учитавање…"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
